@@ -94,20 +94,36 @@ class StructureFind(object):
  
     
     """
-    def __init__(self, cooler_fil, Res, Allelic, GapFile = None, 
-                 Loop_ratio = 0.6, Loop_strength = 16 , n_components = 3):
+    def __init__(self, cooler_fil, Res, Allelic, genomeSize_fil, GapFile = None, 
+                 Loop_ratio = 0.6, Loop_strength = 16, n_components = 3):
         
         #------------Initialization the HiC Matrix Dictionary----------------
         self.cooler_fil = '{}::{}'.format(cooler_fil, Res)
         self.Res = Res
         self.Allelic = Allelic
+        self.genomeSize_fil = genomeSize_fil
         self.Gap_file = GapFile
         self.ratio = Loop_ratio
         self.LoopStrength = Loop_strength
         self.components = n_components
+        chromsizes = self.readChromSize()
+        self.chromsizes = chromsizes
 
 #===============================Public Functions====================================
-
+        
+    def readChromSize(self):
+        """
+            Get the chromatin size.
+        """
+        
+        chromsize = {}
+        with open(self.genomeSize_fil,'r') as source:
+            for line in source:
+                parse = line.strip().split()
+                c, s = parse[0].lstrip('chr'), parse[1]
+                chromsize[c] = int(s)
+        
+        return chromsize
 
     def Sig_update(self, sigs):
         """
@@ -606,6 +622,7 @@ class StructureFind(object):
             cmap = self.Cmap_Setting(types=3,start_Color='#0000FF')
         else:
             raise Exception("Unknown Matrix String %s, Only IF, OE, Cor strings allowed." % MS)
+            
         
         for chro in self.chroms:
             Matrix = Matrix_Dict[chro]
@@ -633,8 +650,14 @@ class StructureFind(object):
                            extent = (0, N, 0, N), vmin = vmin, vmax = vmax, origin = 'lower')
             
             ticks = list(np.linspace(0, N, 5).astype(int))
-            pos = [t * self.Res for t in ticks]
-            labels = [self.properU(p) for p in pos]
+            pos = [t * self.Res for t in ticks[:4]]
+            if self.Allelic == False:
+                labels = [self.properU(p) for p in pos] + [self.properU(self.chromsizes[chro])]
+            elif (self.Allelic == 'Maternal') or (self.Allelic == 'Paternal'):
+                labels = [self.properU(p) for p in pos] + [self.properU(self.chromsizes[chro[1:]])]
+            else:
+                raise Exception ('Unkonwn key word %s, Only Maternal, Paternal, False allowed' % self.Allelic)
+                
             
             ax.set_xticks(ticks)
             ax.set_xticklabels(labels)
